Enum sentry_types::protocol::v7::AttachmentType [−][src]
pub enum AttachmentType {
Attachment,
Minidump,
AppleCrashReport,
UnrealContext,
UnrealLogs,
}Expand description
The different types an attachment can have.
Variants
(default) A standard attachment without special meaning.
A minidump file that creates an error event and is symbolicated. The
file should start with the MDMP magic bytes.
An Apple crash report file that creates an error event and is symbolicated.
An XML file containing UE4 crash meta data. During event ingestion, event contexts and extra fields are extracted from this file.
A plain-text log file obtained from UE4 crashes. During event ingestion, the last logs are extracted into event breadcrumbs.
Implementations