Enum sentry_types::protocol::v7::Level
source · pub enum Level {
Debug,
Info,
Warning,
Error,
Fatal,
}Expand description
Represents the level of severity of an event or breadcrumb.
Variants
Debug
Indicates very spammy debug information.
Info
Informational messages.
Warning
A warning.
Error
An error.
Fatal
Similar to error but indicates a critical event that usually causes a shutdown.
Implementations