Struct sentry_types::protocol::v7::AppleDebugImage [−][src]
pub struct AppleDebugImage {
pub name: String,
pub arch: Option<String>,
pub cpu_type: Option<u32>,
pub cpu_subtype: Option<u32>,
pub image_addr: Addr,
pub image_size: u64,
pub image_vmaddr: Addr,
pub uuid: Uuid,
}Expand description
Represents an apple debug image in the debug meta.
Fields
name: StringThe name of the debug image (usually filename)
arch: Option<String>The optional CPU architecture of the debug image.
cpu_type: Option<u32>Alternatively a macho cpu type.
cpu_subtype: Option<u32>Alternatively a macho cpu subtype.
image_addr: AddrThe starting address of the image.
image_size: u64The size of the image in bytes.
image_vmaddr: AddrThe address where the image is loaded at runtime.
uuid: UuidThe unique UUID of the image.