Struct sentry_types::protocol::v7::ClientSdkInfo [−][src]
pub struct ClientSdkInfo {
pub name: String,
pub version: String,
pub integrations: Vec<String>,
pub packages: Vec<ClientSdkPackage>,
}Expand description
Information on the SDK client.
Fields
name: StringThe name of the SDK.
version: StringThe version of the SDK.
integrations: Vec<String>An optional list of integrations that are enabled in this SDK.
packages: Vec<ClientSdkPackage>An optional list of packages that are installed in the SDK’s environment.