Struct sentry_types::protocol::v7::DeviceContext [−][src]
pub struct DeviceContext {Show fields
pub name: Option<String>,
pub family: Option<String>,
pub model: Option<String>,
pub model_id: Option<String>,
pub arch: Option<String>,
pub battery_level: Option<f32>,
pub orientation: Option<Orientation>,
pub simulator: Option<bool>,
pub memory_size: Option<u64>,
pub free_memory: Option<u64>,
pub usable_memory: Option<u64>,
pub storage_size: Option<u64>,
pub free_storage: Option<u64>,
pub external_storage_size: Option<u64>,
pub external_free_storage: Option<u64>,
pub boot_time: Option<DateTime<Utc>>,
pub timezone: Option<String>,
pub other: Map<String, Value>,
}Expand description
Holds device information.
Fields
name: Option<String>The name of the device.
family: Option<String>The family of the device model.
model: Option<String>The device model (human readable).
model_id: Option<String>The device model (internal identifier).
arch: Option<String>The native cpu architecture of the device.
battery_level: Option<f32>The current battery level (0-100).
orientation: Option<Orientation>The current screen orientation.
simulator: Option<bool>Simulator/prod indicator.
memory_size: Option<u64>Total memory available in byts.
free_memory: Option<u64>How much memory is still available in bytes.
usable_memory: Option<u64>How much memory is usable for the app in bytes.
storage_size: Option<u64>Total storage size of the device in bytes.
free_storage: Option<u64>How much storage is free in bytes.
external_storage_size: Option<u64>Total size of the attached external storage in bytes (eg: android SDK card).
external_free_storage: Option<u64>Free size of the attached external storage in bytes (eg: android SDK card).
boot_time: Option<DateTime<Utc>>Optionally an indicator when the device was booted.
timezone: Option<String>The timezone of the device.
other: Map<String, Value>Additional arbitrary fields for forwards compatibility.