Struct sentry_types::protocol::v7::Frame [−][src]
pub struct Frame {Show fields
pub function: Option<String>,
pub symbol: Option<String>,
pub module: Option<String>,
pub package: Option<String>,
pub filename: Option<String>,
pub abs_path: Option<String>,
pub lineno: Option<u64>,
pub colno: Option<u64>,
pub pre_context: Vec<String>,
pub context_line: Option<String>,
pub post_context: Vec<String>,
pub in_app: Option<bool>,
pub vars: Map<String, Value>,
pub image_addr: Option<Addr>,
pub instruction_addr: Option<Addr>,
pub symbol_addr: Option<Addr>,
pub addr_mode: Option<String>,
}Expand description
Represents a frame.
Fields
function: Option<String>The name of the function is known.
Note that this might include the name of a class as well if that makes sense for the language.
symbol: Option<String>The potentially mangled name of the symbol as it appears in an executable.
This is different from a function name by generally being the mangled name that appears natively in the binary. This is relevant for languages like Swift, C++ or Rust.
module: Option<String>The name of the module the frame is contained in.
Note that this might also include a class name if that is something the language natively considers to be part of the stack (for instance in Java).
package: Option<String>The name of the package that contains the frame.
For instance this can be a dylib for native languages, the name of the jar or .NET assembly.
filename: Option<String>The filename (basename only).
abs_path: Option<String>If known the absolute path.
lineno: Option<u64>The line number if known.
colno: Option<u64>The column number if known.
pre_context: Vec<String>The sources of the lines leading up to the current line.
context_line: Option<String>The current line as source.
post_context: Vec<String>The sources of the lines after the current line.
in_app: Option<bool>In-app indicator.
vars: Map<String, Value>Optional local variables.
image_addr: Option<Addr>If known the location of the image.
instruction_addr: Option<Addr>If known the location of the instruction.
symbol_addr: Option<Addr>If known the location of symbol.
addr_mode: Option<String>Optionally changes the addressing mode. The default value is the same as
"abs" which means absolute referencing. This can also be set to
"rel:DEBUG_ID" or "rel:IMAGE_INDEX" to make addresses relative to an
object referenced by debug id or index. This for instance is necessary
for WASM processing as WASM does not use a unified address space.