Struct sentry_types::protocol::v7::LogEntry [−][src]
Represents a log entry message.
A log message is similar to the message attribute on the event itself but
can additionally hold optional parameters.
Fields
message: StringThe log message with parameters replaced by %s
params: Vec<Value>Positional parameters to be inserted into the log entry.