Struct sentry_types::protocol::v7::Mechanism
source · pub struct Mechanism {
pub ty: String,
pub description: Option<String>,
pub help_link: Option<Url>,
pub handled: Option<bool>,
pub synthetic: Option<bool>,
pub data: Map<String, Value>,
pub meta: MechanismMeta,
}Expand description
Represents a single exception.
Fields
ty: StringThe mechanism type identifier.
description: Option<String>Human readable detail description.
help_link: Option<Url>An optional link to online resources describing this error.
handled: Option<bool>An optional flag indicating whether this exception was handled.
synthetic: Option<bool>An optional flag indicating a synthetic exception.
data: Map<String, Value>Additional attributes depending on the mechanism type.
meta: MechanismMetaOperating system or runtime meta information.