Struct sentry_types::protocol::v7::SessionAttributes [−][src]
pub struct SessionAttributes<'a> {
pub release: Cow<'a, str>,
pub environment: Option<Cow<'a, str>>,
pub ip_address: Option<IpAddr>,
pub user_agent: Option<String>,
}Expand description
Additional attributes for Sessions.
Fields
release: Cow<'a, str>The release version string.
environment: Option<Cow<'a, str>>The environment identifier.
ip_address: Option<IpAddr>The ip address of the user. This data is not persisted but used for filtering.
user_agent: Option<String>The user agent of the user. This data is not persisted but used for filtering.