Struct sentry_types::protocol::v7::SessionUpdate [−][src]
pub struct SessionUpdate<'a> {
pub session_id: Uuid,
pub distinct_id: Option<String>,
pub sequence: Option<u64>,
pub timestamp: Option<DateTime<Utc>>,
pub started: DateTime<Utc>,
pub init: bool,
pub duration: Option<f64>,
pub status: SessionStatus,
pub errors: u64,
pub attributes: SessionAttributes<'a>,
}Expand description
A Release Health Session.
Refer to the Sessions documentation for more details.
Fields
session_id: UuidThe session identifier.
distinct_id: Option<String>The distinct identifier. Should be device or user ID.
sequence: Option<u64>An optional logical clock.
timestamp: Option<DateTime<Utc>>The timestamp of when the session change event was created.
started: DateTime<Utc>The timestamp of when the session itself started.
init: boolA flag that indicates that this is the initial transmission of the session.
duration: Option<f64>An optional duration of the session so far.
status: SessionStatusThe status of the session.
errors: u64The number of errors that ocurred.
attributes: SessionAttributes<'a>The session event attributes.