Struct sentry_types::protocol::v7::Span [−][src]
pub struct Span {
pub span_id: Uuid,
pub trace_id: Uuid,
pub parent_span_id: Option<String>,
pub same_process_as_parent: Option<bool>,
pub op: Option<String>,
pub description: Option<String>,
pub timestamp: Option<DateTime<Utc>>,
pub start_timestamp: DateTime<Utc>,
pub status: Option<String>,
pub tags: Map<String, String>,
pub data: Map<String, Value>,
}Expand description
Represents a tracing span.
Fields
span_id: UuidThe ID of the span
trace_id: UuidDetermines which trace the span belongs to.
parent_span_id: Option<String>Determines the parent of this span, if any.
same_process_as_parent: Option<bool>Determines whether this span is generated in the same process as its parent, if any.
op: Option<String>Short code identifying the type of operation the span is measuring.
description: Option<String>Longer description of the span’s operation, which uniquely identifies the span but is consistent across instances of the span.
timestamp: Option<DateTime<Utc>>The timestamp at the measuring of the span finished.
start_timestamp: DateTime<Utc>The timestamp at the measuring of the span started.
status: Option<String>Describes the status of the span (e.g. ok, cancelled, etc.)
Optional tags to be attached to the span.
data: Map<String, Value>Optional extra information to be sent with the span.
Implementations