Struct sentry_types::protocol::v7::TemplateInfo [−][src]
pub struct TemplateInfo {
pub filename: Option<String>,
pub abs_path: Option<String>,
pub lineno: Option<u64>,
pub colno: Option<u64>,
pub pre_context: Vec<String>,
pub context_line: Option<String>,
pub post_context: Vec<String>,
}Expand description
Represents template debug info.
Fields
filename: Option<String>The filename (basename only).
abs_path: Option<String>If known the absolute path.
lineno: Option<u64>The line number if known.
colno: Option<u64>The column number if known.
pre_context: Vec<String>The sources of the lines leading up to the current line.
context_line: Option<String>The current line as source.
post_context: Vec<String>The sources of the lines after the current line.