Struct sentry_types::protocol::v7::Thread
source · pub struct Thread {
pub id: Option<ThreadId>,
pub name: Option<String>,
pub stacktrace: Option<Stacktrace>,
pub raw_stacktrace: Option<Stacktrace>,
pub crashed: bool,
pub current: bool,
}Expand description
Represents a single thread.
Fields
id: Option<ThreadId>The optional ID of the thread (usually an integer)
name: Option<String>The optional name of the thread.
stacktrace: Option<Stacktrace>If the thread suspended or crashed a stacktrace can be attached here.
raw_stacktrace: Option<Stacktrace>Optional raw stacktrace.
crashed: boolTrue if this is the crashed thread.
current: boolIndicates that the thread was not suspended when the event was created.