Struct sentry_types::protocol::v7::Transaction [−][src]
pub struct Transaction<'a> {
pub event_id: Uuid,
pub name: Option<String>,
pub tags: Map<String, String>,
pub sdk: Option<Cow<'a, ClientSdkInfo>>,
pub platform: Cow<'a, str>,
pub timestamp: Option<DateTime<Utc>>,
pub start_timestamp: DateTime<Utc>,
pub spans: Vec<Span>,
pub contexts: Map<String, Context>,
}Expand description
Represents a tracing transaction.
Fields
event_id: UuidThe ID of the event
name: Option<String>The transaction name.
Optional tags to be attached to the event.
sdk: Option<Cow<'a, ClientSdkInfo>>SDK metadata
platform: Cow<'a, str>A platform identifier for this event.
timestamp: Option<DateTime<Utc>>The end time of the transaction.
start_timestamp: DateTime<Utc>The start time of the transaction.
spans: Vec<Span>The collection of finished spans part of this transaction.
contexts: Map<String, Context>Optional contexts.
Implementations
Creates a new span transaction the current timestamp and random id.
Creates a fully owned version of the transaction.