Struct sentry_types::protocol::v7::TransactionMetadata
source · pub struct TransactionMetadata {
pub id: Uuid,
pub name: String,
pub trace_id: TraceId,
pub relative_start_ns: u64,
pub relative_end_ns: u64,
pub active_thread_id: u64,
}Expand description
Metadata about the transaction associated with the profile
Fields
id: UuidTransaction ID
name: StringTransaction Name
trace_id: TraceIdTrace ID
relative_start_ns: u64Transaction start timestamp in nanoseconds relative to the start of the profiler
relative_end_ns: u64Transaction end timestamp in nanoseconds relative to the start of the profiler
active_thread_id: u64ID of the thread in which the transaction started